@@ -13,14 +13,14 @@ from sqlalchemy.schema import Table
 from types import MethodType
 
 
-class Database:
+class Database(object):
     """Represent a connection to a specific database"""
 
     # Base is a class variable, because it has nothing to do with specific instances of this class
     # Base is used to derive user defined models, and there is a one-to-many relation between models and databases.
     Base = declarative_base() 
 
-    class ModelBase:
+    class ModelBase(object):
         """Base model for a SQLAlchemy declarative model.
         Now provides a lower case table name and an integer primary key.
         """
@@ -109,11 +109,27 @@ Please specify something like '?charset=utf8' explicitly.""")
             return cls
         return ref_table
 
+    @staticmethod
+    def one_to_one(foreign_table_name):
+        """Class decorator, and a one-to-one relationship between two SQLAlchemy models.
+        Parameters:
+        foreign_table_name is the name of the table other than the one decorated by this method.
+        Notice: this method is untested!
+        """
+        foreign_model_name = foreign_table_name.capitalize()
+        foreign_key = '{0}_id'.format(foreign_table_name)
+        def ref_table(cls):
+            table_name = cls.__name__.lower()
+            setattr(cls, foreign_key, Column(Integer, ForeignKey('{0}.id'.format(foreign_table_name))))
+            setattr(cls, foreign_table_name, relationship(foreign_model_name, backref = backref(table_name, uselist = False)))
+            return cls
+        return ref_table
+
     @staticmethod
     def many_to_many(ref_table_name, ref_name = None, backref_name = None, middle_table_name = None):
         """Class Decorator, add a many-to-many relationship between two SQLAlchemy models.
         Parameters:
-        ref_table_name is the destination table name, it is NOT the one which this method decorated on.
+        ref_table_name is the name of the destination table, it is NOT the one decorated by this method.
         ref_name is how this model reference the destination models.
         backref_name is how the destination model reference this model.
         middle_table_name is the middle table name of this many-to-many relationship.
@@ -176,7 +192,7 @@ Please specify something like '?charset=utf8' explicitly.""")
                 return {'polymorphic_identity': child_nickname}
 
         return BaseClass
-   
+
     @staticmethod
     def ref_grandchildren(child, grandchildren):
         """Reference grandchildren. In a join table inheritance, for example, 
